import 'dart:io';

import 'package:translations/translations.dart' as translations;
import 'package:args/args.dart';

import 'package:translations/record.dart';

main(List<String> arguments) async {
  exitCode = 0; //presume success
  const apiKey = 'api-key';
  const tableKey = 'table-key';
  const help = 'help';
  const path = 'path';
  final parser = new ArgParser()
    ..addFlag(help, abbr: 'h', negatable: false)
    ..addOption(path,
        abbr: 'p',
        help: 'Path where the translation files will be created',
        defaultsTo: '.')
    ..addOption(apiKey,
        abbr: 'a', help: 'Your airtable apikey found in your account')
    ..addOption(tableKey,
        abbr: 't',
        help:
            'The key for your table, found in the api board: https://api.airtable.com/v0/YOUR_TABLE_KEY?maxRecords=3.\nThis part of the url should not be encoded');

  ArgResults argResults = parser.parse(arguments);
  // List<String> paths = argResults.rest;
  if (argResults[help] ||
      argResults[apiKey] == null ||
      argResults[tableKey] == null) {
    return print('Usage for script: \n${parser.usage}');
  }
  try {
    List<Record> records = await translations.getAllTranslation(
        apiKey: argResults[apiKey], tableKey: argResults[tableKey]);
    assert(records != null);
    await translations.writeTranslationsFile(
        records: records, path: argResults[path]);
  } on HttpException catch (e) {
    print(e);
  }
}
